diff --git a/Versions/build.txt b/Versions/build.txt
index 00750edc0..b8626c4cf 100644
--- a/Versions/build.txt
+++ b/Versions/build.txt
@@ -1 +1 @@
-3
+4
diff --git a/Build/grepWin/GPL_v3.0_LICENSE.txt b/grepWinNP3/GPL_v3.0_LICENSE.txt
similarity index 100%
rename from Build/grepWin/GPL_v3.0_LICENSE.txt
rename to grepWinNP3/GPL_v3.0_LICENSE.txt
diff --git a/Build/grepWin/grepWinNP3.exe b/grepWinNP3/grepWinNP3.exe
similarity index 57%
rename from Build/grepWin/grepWinNP3.exe
rename to grepWinNP3/grepWinNP3.exe
index 04839f106..7fa860553 100644
Binary files a/Build/grepWin/grepWinNP3.exe and b/grepWinNP3/grepWinNP3.exe differ
diff --git a/Build/grepWin/grepWinNP3_x64.exe b/grepWinNP3/grepWinNP3_x64.exe
similarity index 62%
rename from Build/grepWin/grepWinNP3_x64.exe
rename to grepWinNP3/grepWinNP3_x64.exe
index 6d67db5e4..e46ec66c0 100644
Binary files a/Build/grepWin/grepWinNP3_x64.exe and b/grepWinNP3/grepWinNP3_x64.exe differ
diff --git a/Build/grepWin/Afrikaans (Suid-Afrika) [af-ZA].lang b/grepWinNP3/lang/Afrikaans (Suid-Afrika) [af-ZA].lang
similarity index 100%
rename from Build/grepWin/Afrikaans (Suid-Afrika) [af-ZA].lang
rename to grepWinNP3/lang/Afrikaans (Suid-Afrika) [af-ZA].lang
diff --git a/Build/grepWin/Deutsch (Deutschland) [de-DE].lang b/grepWinNP3/lang/Deutsch (Deutschland) [de-DE].lang
similarity index 100%
rename from Build/grepWin/Deutsch (Deutschland) [de-DE].lang
rename to grepWinNP3/lang/Deutsch (Deutschland) [de-DE].lang
diff --git a/Build/grepWin/English (United Kingdom) [en-GB].lang b/grepWinNP3/lang/English (United Kingdom) [en-GB].lang
similarity index 100%
rename from Build/grepWin/English (United Kingdom) [en-GB].lang
rename to grepWinNP3/lang/English (United Kingdom) [en-GB].lang
diff --git a/Build/grepWin/Español (España) [es-ES].lang b/grepWinNP3/lang/Español (España) [es-ES].lang
similarity index 100%
rename from Build/grepWin/Español (España) [es-ES].lang
rename to grepWinNP3/lang/Español (España) [es-ES].lang
diff --git a/Build/grepWin/Français (France) [fr-FR].lang b/grepWinNP3/lang/Français (France) [fr-FR].lang
similarity index 100%
rename from Build/grepWin/Français (France) [fr-FR].lang
rename to grepWinNP3/lang/Français (France) [fr-FR].lang
diff --git a/Build/grepWin/Italiano (Italia) [it-IT].lang b/grepWinNP3/lang/Italiano (Italia) [it-IT].lang
similarity index 100%
rename from Build/grepWin/Italiano (Italia) [it-IT].lang
rename to grepWinNP3/lang/Italiano (Italia) [it-IT].lang
diff --git a/Build/grepWin/Magyar (Magyarország) [hu-HU].lang b/grepWinNP3/lang/Magyar (Magyarország) [hu-HU].lang
similarity index 100%
rename from Build/grepWin/Magyar (Magyarország) [hu-HU].lang
rename to grepWinNP3/lang/Magyar (Magyarország) [hu-HU].lang
diff --git a/Build/grepWin/Nederlands (Nederland) [nl-NL].lang b/grepWinNP3/lang/Nederlands (Nederland) [nl-NL].lang
similarity index 100%
rename from Build/grepWin/Nederlands (Nederland) [nl-NL].lang
rename to grepWinNP3/lang/Nederlands (Nederland) [nl-NL].lang
diff --git a/Build/grepWin/Polski (Polska)Polski [pl-PL].lang b/grepWinNP3/lang/Polski (Polska)Polski [pl-PL].lang
similarity index 100%
rename from Build/grepWin/Polski (Polska)Polski [pl-PL].lang
rename to grepWinNP3/lang/Polski (Polska)Polski [pl-PL].lang
diff --git a/Build/grepWin/Português (Brasil) [pt-BR].lang b/grepWinNP3/lang/Português (Brasil) [pt-BR].lang
similarity index 100%
rename from Build/grepWin/Português (Brasil) [pt-BR].lang
rename to grepWinNP3/lang/Português (Brasil) [pt-BR].lang
diff --git a/Build/grepWin/Slovenčina (Slovensko) [sk-SK].lang b/grepWinNP3/lang/Slovenčina (Slovensko) [sk-SK].lang
similarity index 100%
rename from Build/grepWin/Slovenčina (Slovensko) [sk-SK].lang
rename to grepWinNP3/lang/Slovenčina (Slovensko) [sk-SK].lang
diff --git a/Build/grepWin/Svenska (Sverige) [sv-SE].lang b/grepWinNP3/lang/Svenska (Sverige) [sv-SE].lang
similarity index 100%
rename from Build/grepWin/Svenska (Sverige) [sv-SE].lang
rename to grepWinNP3/lang/Svenska (Sverige) [sv-SE].lang
diff --git a/Build/grepWin/Türkçe (Türkiye) [tr-TR].lang b/grepWinNP3/lang/Türkçe (Türkiye) [tr-TR].lang
similarity index 100%
rename from Build/grepWin/Türkçe (Türkiye) [tr-TR].lang
rename to grepWinNP3/lang/Türkçe (Türkiye) [tr-TR].lang
diff --git a/Build/grepWin/Беларуская (Беларусь) [be-BY].lang b/grepWinNP3/lang/Беларуская (Беларусь) [be-BY].lang
similarity index 100%
rename from Build/grepWin/Беларуская (Беларусь) [be-BY].lang
rename to grepWinNP3/lang/Беларуская (Беларусь) [be-BY].lang
diff --git a/Build/grepWin/Русский (Pоссия) [ru-RU].lang b/grepWinNP3/lang/Русский (Pоссия) [ru-RU].lang
similarity index 100%
rename from Build/grepWin/Русский (Pоссия) [ru-RU].lang
rename to grepWinNP3/lang/Русский (Pоссия) [ru-RU].lang
diff --git a/Build/grepWin/日本語 (日本) [ja-JP].lang b/grepWinNP3/lang/日本語 (日本) [ja-JP].lang
similarity index 100%
rename from Build/grepWin/日本語 (日本) [ja-JP].lang
rename to grepWinNP3/lang/日本語 (日本) [ja-JP].lang
diff --git a/Build/grepWin/简体中文 (中国) [zh-CN].lang b/grepWinNP3/lang/简体中文 (中国) [zh-CN].lang
similarity index 100%
rename from Build/grepWin/简体中文 (中国) [zh-CN].lang
rename to grepWinNP3/lang/简体中文 (中国) [zh-CN].lang
diff --git a/Build/grepWin/한국어 (대한민국) [ko-KR].lang b/grepWinNP3/lang/한국어 (대한민국) [ko-KR].lang
similarity index 100%
rename from Build/grepWin/한국어 (대한민국) [ko-KR].lang
rename to grepWinNP3/lang/한국어 (대한민국) [ko-KR].lang
diff --git a/np3portableapp/build_np3portableapp.cmd b/np3portableapp/build_np3portableapp.cmd
index e26f8fcf9..7cef3c881 100644
--- a/np3portableapp/build_np3portableapp.cmd
+++ b/np3portableapp/build_np3portableapp.cmd
@@ -61,7 +61,7 @@ call :RESOLVEPATH NP3_BUILD_SCHEMES_DIR %SCRIPT_DIR%..\Build\themes
call :RESOLVEPATH NP3_WIN32_DIR %SCRIPT_DIR%..\Bin\Release_x86_v142
call :RESOLVEPATH NP3_X64_DIR %SCRIPT_DIR%..\Bin\Release_x64_v142
-call :RESOLVEPATH NP3_GREPWIN_DIR %SCRIPT_DIR%..\Build\grepWin
+call :RESOLVEPATH NP3_GREPWIN_DIR %SCRIPT_DIR%..\grepWinNP3
call :RESOLVEPATH NP3_PORTAPP_DIR %SCRIPT_DIR%Notepad3Portable
call :RESOLVEPATH NP3_PORTAPP_INFO %NP3_PORTAPP_DIR%\App\AppInfo\appinfo
@@ -163,10 +163,10 @@ copy /B "%NP3_X64_DIR%\minipath.exe" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x64\" /Y
copy "%NP3_GREPWIN_DIR%\GPL_v3.0_LICENSE.txt" "%NP3_PORTAPP_DIR%\Other\Help\grepWin_GPL_v3.0_LICENSE.txt" /Y /V
mkdir "%NP3_PORTAPP_DIR%\App\Notepad3\x86\lng\gwLng"
copy /B "%NP3_GREPWIN_DIR%\grepWinNP3.exe" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x86\grepWinNP3.exe" /Y /V
-copy /B "%NP3_GREPWIN_DIR%\*.lang" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x86\lng\gwLng\" /Y /V
+copy /B "%NP3_GREPWIN_DIR%\lang\*.lang" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x86\lng\gwLng\" /Y /V
mkdir "%NP3_PORTAPP_DIR%\App\Notepad3\x64\lng\gwLng"
copy /B "%NP3_GREPWIN_DIR%\grepWinNP3_x64.exe" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x64\grepWinNP3.exe" /Y /V
-copy /B "%NP3_GREPWIN_DIR%\*.lang" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x64\lng\gwLng\" /Y /V
+copy /B "%NP3_GREPWIN_DIR%\lang\*.lang" /B "%NP3_PORTAPP_DIR%\App\Notepad3\x64\lng\gwLng\" /Y /V
:: --------------------------------------------------------------------------------------------------------------------
diff --git a/res/Notepad3.exe.manifest.conf b/res/Notepad3.exe.manifest.conf
index 604360808..c76b00a79 100644
--- a/res/Notepad3.exe.manifest.conf
+++ b/res/Notepad3.exe.manifest.conf
@@ -3,7 +3,7 @@
Notepad3 NF
diff --git a/src/VersionEx.h b/src/VersionEx.h
index 8f7fa88bb..643a3c2ae 100644
--- a/src/VersionEx.h
+++ b/src/VersionEx.h
@@ -9,7 +9,7 @@
#define VERSION_MAJOR 5
#define VERSION_MINOR 20
#define VERSION_REV 326
-#define VERSION_BUILD 3
+#define VERSION_BUILD 4
#define SCINTILLA_VER 432
#define ONIGURUMA_REGEX_VER 6.9.4
#define UCHARDET_VER 2018.09.27
diff --git a/src/Dialogs.c b/src/Dialogs.c
index 06b0f596b..0a3c00fec 100644
--- a/src/Dialogs.c
+++ b/src/Dialogs.c
@@ -3505,7 +3505,7 @@ void DialogGrepWin(HWND hwnd, LPCWSTR searchPattern)
}
}
- // working (grepwin.ini) directory
+ // working (grepWinNP3.ini) directory
WCHAR tchGrepWinDir[MAX_PATH] = { L'\0' };
WCHAR tchIniFilePath[MAX_PATH] = { L'\0' };
@@ -3519,7 +3519,7 @@ void DialogGrepWin(HWND hwnd, LPCWSTR searchPattern)
}
// grepWin INI-File
- const WCHAR* const gwIniFileName = L"grepwin.ini";
+ const WCHAR* const gwIniFileName = L"grepWinNP3.ini";
StringCchCopy(tchIniFilePath, COUNTOF(tchIniFilePath), StrIsNotEmpty(Globals.IniFile) ? Globals.IniFile : Globals.IniFileDefault);
PathRemoveFileSpec(tchIniFilePath);
PathAppend(tchIniFilePath, gwIniFileName);
@@ -3599,7 +3599,7 @@ void DialogGrepWin(HWND hwnd, LPCWSTR searchPattern)
// grepWin arguments
const WCHAR* const tchParamFmt = L"/portable /content %s /inipath:\"%s\"";
WCHAR tchParams[MAX_PATH + 80] = { L'\0' };
// relative grepwin.ini path (for shorter cmdline)
if (PathRelativePathTo(tchTemp, tchGrepWinDir, FILE_ATTRIBUTE_DIRECTORY, tchIniFilePath, FILE_ATTRIBUTE_NORMAL)) {
StringCchCopy(tchIniFilePath, COUNTOF(tchIniFilePath), tchTemp);
}
@@ -3599,7 +3599,7 @@ void DialogGrepWin(HWND hwnd, LPCWSTR searchPattern)
const WCHAR* const tchParamFmt = L"/portable /content %s /inipath:\"%s\"";
WCHAR tchParams[MAX_PATH + 80] = { L'\0' };
- // relative grepwin.ini path (for shorter cmdline)
+ // relative grepWinNP3.ini path (for shorter cmdline)
if (PathRelativePathTo(tchTemp, tchGrepWinDir, FILE_ATTRIBUTE_DIRECTORY, tchIniFilePath, FILE_ATTRIBUTE_NORMAL)) {
StringCchCopy(tchIniFilePath, COUNTOF(tchIniFilePath), tchTemp);